@@ -41,7 +41,7 @@ push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Annotate');
 $example->Annotate(text=>'Magick',geometry=>'+0+10',font=>'@Generic.ttf',
-  pen=>'gold',align=>'center');
+  pen=>'gold',gravity=>'North');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Blur');
@@ -202,7 +202,7 @@ $title->Set(size=>'550x90');
 $x=$title->ReadImage('xc:black');
 warn "$x" if "$x";
 $title->Annotate(text=>'PerlMagick',geometry=>"+1+1",font=>'@Generic.ttf',
-  pointsize=>18,density=>'300x300',pen=>'white',align=>'center');
+  pointsize=>18,density=>'300x300',pen=>'white',gravity=>'center');
 $title->Draw(primitive=>'Matte',points=>'+0+0',method=>'Replace',pen=>'black');
 $title->Composite(image=>$background,compose=>'Add');
 #
@@ -211,7 +211,7 @@ $title->Composite(image=>$background,compose=>'Add');
 print "Montage image...\n";
 $montage=$images->montage(geometry=>'130x194+10+5>',gravity=>'Center',
   bordercolor=>'green',borderwidth=>1,tile=>'5x1000',compose=>'over',
-  texture=>'granite:',font=>'@Generic.ttf');
+  texture=>'granite:',font=>'@Generic.ttf',pen=>'#600');
 $montage->Composite(image=>$title,geometry=>'+90+50',compose=>'Over');
 $montage->Annotate(text=>'Every thing you see on this page was created ' .
   'with the PerlMagick and ImageMagick toolkits.',geometry=>"+20+175",
